@@ -17,10 +17,10 @@ class TestTLS:
         # Make sure we actually use encryption, access via plain
         # HTTP shall fail.
         async with aiohttp.ClientSession() as session:
-            with pytest.raises(aiotus.ProtocolError) as excinfo:
+            with pytest.raises(aiohttp.ClientResponseError) as excinfo:
                 http_url = nginx_proxy.url.with_scheme("http")
                 await aiotus.creation.create(session, http_url, memory_file, {})
-            assert "Wrong status code" in str(excinfo.value)
+            assert excinfo.value.status == 400
 
         # As we use a self-signed certificate, the connection will fail.
         async with aiohttp.ClientSession() as session:
